# Std libraries
from django import template

register = template.Library()

PERCENTAGE_DEFAULT_CLASSES = {
    'negative': 'negative',
    'positive': 'positive'
}

@register.filter()
def colorize_percentage(value):
    """
    Colorizes value depending on if it is less (default color red) or more
    (default color green) than zero. Indented usage in determining what
    direction certain stock value changes during a day (hence the
    _percentage postfix) 
    
    Example:

       {{ data.change|colorize_percentage }}

    :param value: (percentage) value based on which colorizing is done
    :type value: decimal.Decimal (or any that can be compared to 0)
    :return: color name to be used as css class
    :rtype: string
    """
    
    if value >= 0:
        return PERCENTAGE_DEFAULT_CLASSES['positive']
    else:
        return PERCENTAGE_DEFAULT_CLASSES['negative']




#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys

import pjcore

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

version = pjcore.__version__

if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    os.system('python setup.py bdist_wheel upload')
    sys.exit()

if sys.argv[-1] == 'tag':
    print("Tagging the version on github:")
    os.system("git tag -a v%s -m 'version %s'" % (version, version))
    os.system("git push --tags")
    sys.exit()

readme = open('README.rst').read()
history = open('HISTORY.rst').read().replace('.. :changelog:', '')

setup(
    name='django-pj-core',
    version=version,
    description="""Misc utilities for Django""",
    long_description=readme + '\n\n' + history,
    author='Petri Jokimies',
    author_email='petri.jokimies@gmail.com',
    url='https://github.com/jokimies/django-pj-core',
    packages=[
        'pjcore',
    ],
    include_package_data=True,
    install_requires=[
    ],
    license="BSD",
    zip_safe=False,
    keywords='django-pj-core',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],
)
